Page 74 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 74

Home

    referred to as "the golden city," Isaiah 14:4.

    The second metal mentioned in Scripture is in
    reference to Abram (Abraham). It is found in Genesis
    13:2, "and Abram was very rich in cattle, in silver, and

    in gold.”

    That these two metals were placed in the earth by the
    Creator shows His infinite wisdom in providing man a
    basis for a universal monetary system. The creation of
    gold and silver was one of God's great masterpieces that

    civilized society.

    The use of gold and silver as money did not come
    about as the result of any government decree or even of
    Divine commandment. It came about as a result of the

    choice (often by trial and error) of the people themselves.
    This choice was made for several reasons.

    Gold and silver are universally desired as objects of
    beauty, especially in the form of jewelry. They are
    durable, even when lying in the ground for thousands of
    years. They are divisible, and can be formed into any
    size or shape. They are also scarce and cannot be
    produced by any process known to man. These
    characteristics make gold and silver an ideal store of
    wealth, which is what real money is.

    The Founding Fathers of the American Republic
    understood the basis of real money, thus, in the
    Constitution it is spelled out that, "No State shall...
    make anything but gold and silver coin a tender in

    These

    69

    The American Republic

    which may have been the reason for it having been

    enabled man to develop a system of commerce in a